@@ -27,27 +27,48 @@ Author:
 """
 
 from __future__ import annotations
+from distutils.util import strtobool
 
 from logging import INFO, StreamHandler, basicConfig
+from os import getenv
 import re
-from typing import ClassVar, Dict, Optional
+from typing import ClassVar, Dict, List, Optional
 
 from python_json_log_formatter.context_filter import ContextFilter
 
 
-VERSION = "3.0.1"
+VERSION = "3.2.0"
 
 class PythonLogger:
+    """This class wraps functions used for logging for an easier, direct access.
+
+    Methods:
+        setup_logger - Configures the root as required. To be called before any logging commands in the main file (very top).
+        update_context -
+
+    Raises:
+        ValueError: _description_
+    """
 
     __context_filter: ClassVar[ContextFilter]
 
+    @property
+    def excluded_logging_context_keys(self) -> List[str]:
+        """Keys of the logging Record which should not be included automatically."""
+        return self.__context_filter.excluded_logging_context_keys
+
+    @excluded_logging_context_keys.setter
+    def excluded_logging_context_keys(self, value: List[str]) -> None:
+        self.__context_filter.excluded_logging_context_keys = value
+
     @classmethod
     def setup_logger(cls,
                      version_constant: str,
                      app: Optional[str],
                      extra_context_dict: Optional[Dict[str, str]] = None,
-                     logging_level: int = INFO) -> None:
-        """Setups the root logger of the system. To be called before any logging commands in the main file (very top).
+                     logging_level: int = INFO,
+                     disable_log_formatting: Optional[bool] = None) -> None:
+        """Configures the root as required. To be called before any logging commands in the main file (very top).
 
         Sets the logging format for the root logger and thus for every child logger.
         In EVERY file where logging happens, please use `LOGGER = logging.getLogger(__name__)` to get an individual logger.
@@ -60,7 +81,8 @@ class PythonLogger:
             version_constant (str): Program version, requires semantic version format '1.0.0' with a prefix '(yyyy/mm/dd)'
             app (str): Name of the app for the logger.
             extra_context_dict (Dict[str, str]): additional logging information like 'env', 'processing_id' and more.
-            logging_level (int, optional): Log level of root logger. Defaults to INFO.
+            logging_level (int): Log level of root logger. Defaults to INFO.
+            disable_log_formatting (bool, optional): Disable the log formatting, e.g. local development. Defaults to None/False.
 
         Raises:
             ValueError: Incorrect version format supplied
@@ -73,20 +95,33 @@ class PythonLogger:
         if not version_match:
             raise ValueError("Incorrect version format. Please use semantic versioning and prepend optionally '(yyyy/mm/dd)':https://semver.org/#semantic-versioning-specification-semver  https://ihateregex.io/expr/semver/")
 
+        if disable_log_formatting is None:
+            disable_log_formatting =  bool(strtobool(
+                getenv("DISABLE_LOG_FORMATTING", "False")
+                ))
+
         handler = StreamHandler()
 
         context_dict = extra_context_dict or {}
         if app:
             context_dict["app"] = app
         context_dict["version"] = version_constant
-        cls.__context_filter = ContextFilter(context_dict)
+        cls.__context_filter = ContextFilter(context_dict, disable_log_formatting)
         handler.addFilter(cls.__context_filter)
         basicConfig(
             level=logging_level,
-            format="%(asctime)s %(name)s] %(levelname)s: %(message)s",
+            format="[%(asctime)s %(name)s] %(levelname)s: %(message)s",
             handlers=[handler]
     )
 
     @classmethod
     def update_context(cls, context: Dict[str, str]) -> None:
+        """Updates additional context information added to each log line.
+
+        Will update the existing context with the given one, overwriting existing keys.
+        Existing keys without a new match will not be deleted
+
+        Args:
+            context (Dict[str, str]): context information to be included in each log line
+        """
         cls.__context_filter.update_context(context)
\ No newline at end of file
